@@ -10,7 +10,7 @@ except ImportError:
 os.environ['DJANGO_SETTINGS_MODULE'] = 'pages.testproj.test_settings'
 current_dirname = os.path.dirname(__file__)
 sys.path.insert(0, current_dirname)
-sys.path.insert(0, os.path.join(current_dirname, '../..'))
+sys.path.insert(0, os.path.join(current_dirname, '..'))
 
 from django.test.simple import run_tests as django_test_runner
 from django.db.models import get_app, get_apps
@@ -66,7 +66,7 @@ def get_all_coverage_modules(app_module, exclude_patterns=[]):
     return mod_list
 
 
-def run_tests(test_labels=('pages',), verbosity=1, interactive=True,
+def run_tests(test_labels=('pages', ), verbosity=1, interactive=True,
         extra_tests=[]):
 
     if coverage:
@@ -88,4 +88,7 @@ def run_tests(test_labels=('pages',), verbosity=1, interactive=True,
 
 
 if __name__ == '__main__':
-    run_tests()
+    if len(sys.argv) > 1:
+        run_tests(test_labels=(sys.argv[1], ))
+    else:
+        run_tests()
